@@ -1,19 +1,37 @@
 #' Build Lines
 #'
 #'
-#' \code{build_lines} creates a \code{SpatialLines} object from a \code{data.table}. The function accepts a \code{data.table} with relocation data, individual identifiers a sorting column and a \code{projection}. The relocation data is transformed into \code{SpatialLines} for each individual and optionally, each \code{splitBy}. Relocation data should be in two columns representing the X and Y coordinates.
+#' \code{build_lines} creates a \code{SpatialLines} object from a \code{data.table}.
+#' The function accepts a \code{data.table} with relocation data, individual
+#' identifiers a sorting column and a \code{projection}. The relocation data
+#' is transformed into \code{SpatialLines} for each individual and optionally,
+#' each \code{splitBy}. Relocation data should be in two columns representing
+#' the X and Y coordinates.
 #'
-#' The \code{projection} argument expects a character string defining the EPSG code. For example, for UTM zone 21N (EPSG 32736), the projection argument is "+init=epsg:32736". See \url{https://spatialreference.org} for a list of EPSG codes. Please note, R spatial has followed updates to GDAL and PROJ for handling projections, see more at \url{https://www.r-spatial.org/r/2020/03/17/wkt.html}.
+#' The \code{projection} argument expects a character string defining the EPSG
+#' code. For example, for UTM zone 36N (EPSG 32736), the projection argument is
+#'  'EPSG:32736'. See \url{https://spatialreference.org} for a list of
+#'  EPSG codes. Please note, R spatial has followed updates to GDAL and PROJ
+#'  for handling projections, see more at
+#'  \url{https://www.r-spatial.org/r/2020/03/17/wkt.html}.
 #'
-#' The \code{sortBy} is used to order the input \code{data.table} when creating \code{SpatialLines}. It must a \code{POSIXct} to ensure the rows are sorted by date time.
+#' The \code{sortBy} is used to order the input \code{data.table} when creating
+#' \code{SpatialLines}. It must a \code{POSIXct} to ensure the rows are sorted
+#' by date time.
 #'
-#' The \code{splitBy} argument offers further control building \code{SpatialLines}. If in your \code{DT}, you have multiple temporal groups (e.g.: years) for example, you can provide the name of the column which identifies them and build \code{SpatialLines} for each individual in each year.
+#' The \code{splitBy} argument offers further control building \code{SpatialLines}.
+#' If in your \code{DT}, you have multiple temporal groups (e.g.: years) for
+#' example, you can provide the name of the column which identifies them and
+#' build \code{SpatialLines} for each individual in each year.
 #'
-#' \code{build_lines} is used by \code{group_lines} for grouping overlapping lines created from relocations.
+#' \code{build_lines} is used by \code{group_lines} for grouping overlapping
+#' lines created from relocations.
 #'
-#' @return \code{build_lines} returns a \code{SpatialLines} object with a line for each individual (and optionally \code{splitBy} combination).
+#' @return \code{build_lines} returns a \code{SpatialLines} object with a line
+#' for each individual (and optionally \code{splitBy} combination).
 #'
-#' An error is returned when an individual has less than 2 relocations, making it impossible to build a line.
+#' An error is returned when an individual has less than 2 relocations, making
+#' it impossible to build a line.
 #'
 #' @inheritParams group_lines
 #' @inheritParams build_polys
@@ -36,15 +54,15 @@
 #' DT[, datetime := as.POSIXct(datetime, tz = 'UTC')]
 #'
 #' # EPSG code for example data
-#' utm <- '+init=epsg:32736'
+#' utm <- 'EPSG:32736'
 #'
 #' # Build lines for each individual
-#' build_lines(DT, projection = utm, id = 'ID', coords = c('X', 'Y'),
+#' lines <- build_lines(DT, projection = utm, id = 'ID', coords = c('X', 'Y'),
 #'             sortBy = 'datetime')
 #'
 #' # Build lines for each individual by year
 #' DT[, yr := year(datetime)]
-#' build_lines(DT, projection = utm, id = 'ID', coords = c('X', 'Y'),
+#' lines <- build_lines(DT, projection = utm, id = 'ID', coords = c('X', 'Y'),
 #'             sortBy = 'datetime', splitBy = 'yr')
 #'
 build_lines <-
@@ -131,13 +149,14 @@ build_lines <-
     if (length(lst) == 0) {
       return(NULL)
     } else {
+      proj4string <- sp::CRS(projection)
       l <- lapply(seq_along(lst), function(i) {
         sp::SpatialLines(list(sp::Lines(sp::Line(
           cbind(lst[[i]][[coords[1]]],
                 lst[[i]][[coords[2]]])
         ),
         names(lst)[[i]])),
-        proj4string = sp::CRS(projection))
+        proj4string = proj4string)
       })
       return(do.call(sp::rbind.SpatialLines, l))
     }
