@@ -18,7 +18,7 @@ test_that('ID and coords column names, threshold correctly provided',
             expect_error(edge_dist(DT, threshold = 10, id = NULL),
                          'ID field required')
 
-            expect_error(edge_dist(DT, threshold = NULL, id = 'ID'),
+            expect_error(edge_dist(DT, id = 'ID'),
                          'threshold required')
 
             expect_error(
@@ -92,13 +92,6 @@ test_that('column names must exist in DT', {
 
 test_that('threshold correctly provided or error detected', {
   copyDT <- copy(DT)
-  expect_silent(edge_dist(
-    copyDT,
-    threshold = 10,
-    id = 'ID',
-    coords = c('X', 'Y'),
-    timegroup = NULL
-  ))
 
   expect_error(edge_dist(DT, threshold = -10, id = 'ID'),
                'threshold must be greater than 0')
@@ -288,3 +281,14 @@ test_that('returnDist works', {
             thresh)
 
 })
+
+
+test_that('returns a data.table', {
+  expect_s3_class(edge_dist(
+    DT,
+    threshold = 10,
+    id = 'ID',
+    coords = c('X', 'Y'),
+    timegroup = NULL
+  ), 'data.table')
+})
